ClockConfig

Struct ClockConfig 

pub struct ClockConfig {
Show 13 fields pub xtal_clk: Option<XtalClkConfig>, pub soc_root_clk: Option<SocRootClkConfig>, pub cpu_hs_div: Option<CpuHsDivConfig>, pub cpu_ls_div: Option<CpuLsDivConfig>, pub ahb_hs_div: Option<AhbHsDivConfig>, pub ahb_ls_div: Option<AhbLsDivConfig>, pub apb_clk: Option<ApbClkConfig>, pub mspi_fast_hs_clk: Option<MspiFastHsClkConfig>, pub mspi_fast_ls_clk: Option<MspiFastLsClkConfig>, pub ledc_sclk: Option<LedcSclkConfig>, pub lp_fast_clk: Option<LpFastClkConfig>, pub lp_slow_clk: Option<LpSlowClkConfig>, pub timg_calibration_clock: Option<TimgCalibrationClockConfig>,
}
Available on crate feature unstable only.
Clock tree configuration.

The fields of this struct are optional, with the following caveats:

  • If XTAL_CLK is not specified, the crystal frequency will be automatically detected if possible.
  • The CPU and its upstream clock nodes will be set to a default configuration.
  • Other unspecified clock sources will not be useable by peripherals.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Fields

xtal_clk: Option<XtalClkConfig>

XTAL_CLK configuration.

soc_root_clk: Option<SocRootClkConfig>

SOC_ROOT_CLK configuration.

cpu_hs_div: Option<CpuHsDivConfig>

CPU_HS_DIV configuration.

cpu_ls_div: Option<CpuLsDivConfig>

CPU_LS_DIV configuration.

ahb_hs_div: Option<AhbHsDivConfig>

AHB_HS_DIV configuration.

ahb_ls_div: Option<AhbLsDivConfig>

AHB_LS_DIV configuration.

apb_clk: Option<ApbClkConfig>

APB_CLK configuration.

mspi_fast_hs_clk: Option<MspiFastHsClkConfig>

MSPI_FAST_HS_CLK configuration.

mspi_fast_ls_clk: Option<MspiFastLsClkConfig>

MSPI_FAST_LS_CLK configuration.

ledc_sclk: Option<LedcSclkConfig>

LEDC_SCLK configuration.

lp_fast_clk: Option<LpFastClkConfig>

LP_FAST_CLK configuration.

lp_slow_clk: Option<LpSlowClkConfig>

LP_SLOW_CLK configuration.

timg_calibration_clock: Option<TimgCalibrationClockConfig>

TIMG_CALIBRATION_CLOCK configuration.